// remove /**/ for debugging
//var console = {};
//console.log = function() {};

/**
 * This module uses the popups infrastructure to build popupss that can show a drupal page.
 * Any link can trigger this effect by setting the attribute popups=1.
 * This module can also be used to build other types of popupss.
 * Here is an example:
 * Drupal.popups.prototype.open_unsaved = function( a ) {
 *   body = Drupal.t("There are unsaved changes on this page.");
 *   buttons = {
 *    'popups_save': { title: Drupal.t('Save Changes'), func: function(){$('#edit-submit').click()} },
 *    'popups_submit': { title: Drupal.t('Discard Changes and Continue'), func: function(){window.location = a.href} },
 *    'popups_cancel': { title: Drupal.t('Cancel'), func: this.close }
 *  };
 *  this.open( "Warning - Please Confirm", body, buttons );
 *  return false;
 * };
 */

Drupal.behaviors.popups = function(context) {
  var popups = new Drupal.popups();
  $('a[popups]', context).click( function(){ return popups.open_path(this, 800); } );
//  $('a[popups]', context).click( function(){ console.log('click'); return false; } );
};

Drupal.popups = function() {
  this.default_width = 480;
};

Drupal.popups.prototype.add_overlay = function() {
  var overlay = $( Drupal.theme('popupssOverlay') );

  overlay.css( 'opacity', '0.4' ); // for ie
  $('body').prepend( overlay );
  return overlay;
};

Drupal.popups.prototype.open = function( title, body, buttons, width, overlay ) {
  if( !width ) {
    width = this.default_width;
  }

  if( !overlay ) {
    overlay = this.add_overlay();
  }
    
  // center on the screen, add in offsets if the window has been scrolled
  var overlay_width = overlay.width();
  var overlay_height = overlay.height();
  var left = (overlay_width / 2) - (width / 2) + f_scrollLeft();
  var top = 0; // we will reposition after adding to page
  var popups = Drupal.theme('popupssDialog', left, top, width, title, body, buttons);

  overlay.before( popups ); // popups is added, but still hidden.  

  // Adding button functions
  for ( var id in buttons) {
    var func = buttons[id].func;
    $('#'+id).click( func );
  }
  $('#popups-close').click( this.close );
  
  //Get popups's height on the page, and center vertically before showing.
  var popups_height = $('#popups').height();
  if( popups_height < overlay_height ) {
    top = ( overlay_height / 2 ) - ( popups_height / 2 ) + f_scrollTop();
  }
  else { // popups is too big to fit on screen
    top = 20  + f_scrollTop();
  }
  $('#popups').css('top', top);
  $('#popups').css('display', 'block'); // center and reveal
  
  return false;
};

Drupal.popups.prototype.open_path = function( a, width, height ) {
  var url = a.href;
  var popups = this;
  // let the user know something is happening
  $('body').css("cursor", "wait");
  var overlay = this.add_overlay(); 

  // loaded the link's path into the popups, instead going to new page  
  $.get(Drupal.settings.popups.base_path + "popups/raw?path="+url, function(data) {
     var title = $(data).eq(0).html();
     var body = $(data).slice(1).html();
//     console.log( "got result: " + data + ", title: " + title + ", body: " + body );
     popups.open( title, body, null, 600, overlay );
    $('body').css("cursor", "auto");
  });        
  return false;         
}

Drupal.popups.prototype.close = function() {
  $('#popups').remove();
  $('#popups-overlay').remove();
};

Drupal.theme.prototype.popupssOverlay = function () {
  return '<div id="popups-overlay"></div>';
};

Drupal.theme.prototype.popupssDialog = function(left, top, width, title, body, buttons) {
  var popups = '<div  id="popups" style="display:none; left:'+ left +'px; top:'+ top +'px;';
  popups += ' width:'+ width +'px;';
  popups += '" >';
  popups += '<div id="popups-title">'+
            '  <div class="title">' + title +'</div>'+
            '  <div id="popups-close"><a>close [X]</a></div>'+
            '  <div class="clear"></div>'+
            '</div>';
  popups += '<div id="popups-body">' + body +'</div>';
  popups += '  <div id="popups-buttons">';

  for ( id in buttons) {
    button = buttons[id];
    popups += '<input type="button" value="'+ button.title +'" id="'+ id +'" />';
  }
  
  popups += '  </div>'; // end buttons
  popups +=  '</div>'; // close popups
  return popups;
};

/**
 *
 * Utility functions taken from http://www.softcomplex.com/docs/get_window_size_and_scrollbar_position.html
 *
 */

function f_scrollLeft() {
  return f_filterResults (
    window.pageXOffset ? window.pageXOffset : 0,
    document.documentElement ? document.documentElement.scrollLeft : 0,
    document.body ? document.body.scrollLeft : 0
  );
};
function f_scrollTop() {
  return f_filterResults (
    window.pageYOffset ? window.pageYOffset : 0,
    document.documentElement ? document.documentElement.scrollTop : 0,
    document.body ? document.body.scrollTop : 0
  );
};
function f_filterResults(n_win, n_docel, n_body) {
  var n_result = n_win ? n_win : 0;
  if (n_docel && (!n_result || (n_result > n_docel)))
    n_result = n_docel;
  return n_body && (!n_result || (n_result > n_body)) ? n_body : n_result;
};
